package main

import (
	"errors"
	"html/template"
	"log"
	"net/http"

	"git.c3pb.de/gbe/invinoveritas/auth"
)

var userTemplate = template.Must(template.ParseFS(templateFS, "templates/base.tpl", "templates/user.tpl"))

func (h Handler) user(w http.ResponseWriter, r *http.Request) {
	logRequest(r)

	user := auth.Get(r)

	data := struct {
		User       auth.User
		FormErrors map[string]error
		Success    bool
		ShowResult bool
	}{
		User:       user,
		FormErrors: make(map[string]error),
	}

	if r.Method == "GET" {
		err := userTemplate.ExecuteTemplate(w, "user.tpl", data)
		if err != nil {
			log.Println("can't execute details template:", err)
		}

		return
	}

	if r.Method != "POST" {
		httpError(w, "bad method", errors.New(r.Method), http.StatusMethodNotAllowed)
		return
	}

	data.ShowResult = true

	err := r.ParseForm()
	if err != nil {
		httpError(w, "can't parse POST form", err, http.StatusInternalServerError)
		return
	}

	log.Println("POST form:", r.PostForm)

	defer func() {
		err := userTemplate.ExecuteTemplate(w, "user.tpl", data)
		if err != nil {
			log.Println("can't execute details template:", err)
		}
	}()

	if r.PostForm.Get("new-pw") != r.PostForm.Get("new-pw-repeat") {
		data.FormErrors["NewPW"] = errors.New("new passwords don't match")
		return
	}

	if len(r.PostForm.Get("new-pw")) == 0 {
		data.FormErrors["NewPW"] = errors.New("new password can't be empty")
		return
	}

	err = h.ap.updatePassword(r.Context(), user.Name, r.PostForm.Get("old-pw"), r.PostForm.Get("new-pw"))
	if err != nil {
		data.FormErrors["OldPW"] = err
		return
	}

	data.Success = true
}
